@@ -1,11 +1,12 @@
 package App::CalendarDatesUtils;
 
-our $DATE = '2019-05-25'; # DATE
-our $VERSION = '0.004'; # VERSION
+our $DATE = '2019-05-28'; # DATE
+our $VERSION = '0.005'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
 use warnings;
+#use Log::ger;
 
 our %SPEC;
 
@@ -72,6 +73,10 @@ _
             schema => 'bool*',
             cmdline_aliases => {l=>{}},
         },
+        past => {
+            schema => 'bool*',
+            'summary' => "Filter entries that are less than (at least) today's date",
+        },
     },
     args_rels => {
         'req_one&' => [
@@ -85,7 +90,14 @@ _
 sub list_calendar_dates {
     my %args = @_;
 
-    my $year = $args{year} // (localtime)[5]+1900;
+    my @lt = localtime;
+    my $year_today = $lt[5]+1900;
+    my $mon_today  = $lt[4]+1;
+    my $day_today  = $lt[3];
+    #log_trace "date_today: %04d-%02d-%02d", $year_today, $mon_today, $day_today;
+    #my $date_today = sprintf "%04d-%02d-%02d", $year_today, $mon_today, $day_today;
+
+    my $year = $args{year} // $year_today;
     my $mon  = $args{month};
     my $day  = $args{day};
 
@@ -122,7 +134,17 @@ sub list_calendar_dates {
                 warn "Can't get entries from $mod (year=$y): $@, skipped";
                 next;
             }
-            push @rows, @$res;
+            for my $item (@$res) {
+                if (defined $args{past}) {
+                    my $date_cmp =
+                        $item->{year}  <=> $year_today ||
+                        $item->{month} <=> $mon_today  ||
+                        $item->{day}   <=> $day_today;
+                    next if  $args{past} &&  $date_cmp >  0;
+                    next if !$args{past} &&  $date_cmp <= 0;
+                }
+                push @rows, $item;
+            }
         }
     }
 
@@ -148,7 +170,7 @@ App::CalendarDatesUtils - Utilities related to Calendar::Dates
 
 =head1 VERSION
 
-This document describes version 0.004 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-05-25.
+This document describes version 0.005 of App::CalendarDatesUtils (from Perl distribution App-CalendarDatesUtils), released on 2019-05-28.
 
 =head1 DESCRIPTION
 
@@ -199,6 +221,10 @@ List dates from all available years instead of a single year.
 
 Specify parameters.
 
+=item * B<past> => I<bool>
+
+Filter entries that are less than (at least) today's date.
+
 =item * B<year> => I<int>
 
 Specify year of dates to list.
